==> qtjambi-qt3drender-5.15.5-sources.jar: io/qt/qt3d/render/QBufferDataGenerator.java <==
package io.qt.qt3d.render;


/**
 * <p>Provides a mechanism to generate buffer data from a job</p>
 * <p>Java wrapper for Qt class <a href="http://doc.qt.io/qt-5/qt3drender-qbufferdatagenerator.html">Qt3DRender::QBufferDataGenerator</a></p>
 */
public interface QBufferDataGenerator extends io.qt.QtObjectInterface, io.qt.qt3d.render.QAbstractFunctor
{
    /**
     * <p>Implementor class for interface {@link io.qt.qt3d.render.QBufferDataGenerator}</p>
     */
    public static abstract class Impl extends io.qt.QtObject
        implements io.qt.qt3d.render.QBufferDataGenerator,
                io.qt.qt3d.render.QAbstractFunctor
    {
        static {
            QtJambi_LibraryUtilities.initialize();
        }
        
        @io.qt.NativeAccess
        private static final class ConcreteWrapper extends QBufferDataGenerator.Impl {
            
            @io.qt.NativeAccess
            private ConcreteWrapper(QPrivateConstructor p) { super(p); }
            
            @Override
            @io.qt.QtUninvokable
            public io.qt.core.QByteArray get(){
                return get_native(QtJambi_LibraryUtilities.internal.nativeId(this));
            }
            private native static io.qt.core.QByteArray get_native(long __this__nativeId);
            
            
            @Override
            @io.qt.QtUninvokable
            public boolean equals(io.qt.qt3d.render.QBufferDataGenerator other){
                java.util.Objects.requireNonNull(other, "Argument 'other': null not expected.");
                return equals_native_cref_Qt3DRender_QBufferDataGenerator_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(other));
            }
            private native static boolean equals_native_cref_Qt3DRender_QBufferDataGenerator_constfct(long __this__nativeId, long other);
            
        }
        
        
        public Impl(){
            super((QPrivateConstructor)null);
            initialize_native(this);
        }
        
        private native static void initialize_native(QBufferDataGenerator instance);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qbufferdatagenerator.html#operator-28-29">Qt3DRender::QBufferDataGenerator::operator()()</a></p>
         */
        @io.qt.QtUninvokable
        public abstract io.qt.core.QByteArray get();
        
        private native static io.qt.core.QByteArray get_native(long __this__nativeId);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qbufferdatagenerator.html#operator-eq-eq">Qt3DRender::QBufferDataGenerator::operator==(Qt3DRender::QBufferDataGenerator)const</a></p>
         */
        @io.qt.QtUninvokable
        public abstract boolean equals(io.qt.qt3d.render.QBufferDataGenerator other);
        
        private native static boolean equals_native_cref_Qt3DRender_QBufferDataGenerator_constfct(long __this__nativeId, long other);
        
        /**
         * Constructor for internal use only.
         * @param p expected to be <code>null</code>.
         */
        @io.qt.NativeAccess
        protected Impl(QPrivateConstructor p) { super(p); } 
        

        @Override
        @io.qt.QtUninvokable
        public boolean equals(Object other) {
            if (other instanceof io.qt.qt3d.render.QBufferDataGenerator) {
                return equals((io.qt.qt3d.render.QBufferDataGenerator) other);
            }

            return false;
        }

    }

    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qbufferdatagenerator.html#operator-28-29">Qt3DRender::QBufferDataGenerator::operator()()</a></p>
     */
    @io.qt.QtUninvokable
    public io.qt.core.QByteArray get();
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qbufferdatagenerator.html#operator-eq-eq">Qt3DRender::QBufferDataGenerator::operator==(Qt3DRender::QBufferDataGenerator)const</a></p>
     */
    @io.qt.QtUninvokable
    public default boolean equals(io.qt.qt3d.render.QBufferDataGenerator other){
        return this==other;
    }
    
}

==> qtjambi-qt3drender-5.15.13-sources.jar: io/qt/qt3d/render/QBufferDataGenerator.java <==
package io.qt.qt3d.render;


/**
 * <p>Provides a mechanism to generate buffer data from a job</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qt3drender-qbufferdatagenerator.html">Qt3DRender::QBufferDataGenerator</a></p>
 */
public interface QBufferDataGenerator extends io.qt.QtObjectInterface, io.qt.qt3d.render.QAbstractFunctor
{
    /**
     * <p>Implementor class for interface {@link io.qt.qt3d.render.QBufferDataGenerator}</p>
     */
    public static abstract class Impl extends io.qt.QtObject
        implements io.qt.qt3d.render.QBufferDataGenerator,
                io.qt.qt3d.render.QAbstractFunctor
    {
        static {
            QtJambi_LibraryUtilities.initialize();
        }
        
        @io.qt.NativeAccess
        private static final class ConcreteWrapper extends QBufferDataGenerator.Impl {
            
            @io.qt.NativeAccess
            private ConcreteWrapper(QPrivateConstructor p) { super(p); }
            
            @Override
            @io.qt.QtUninvokable
            public io.qt.core.QByteArray get(){
                return get_native(QtJambi_LibraryUtilities.internal.nativeId(this));
            }
            private native static io.qt.core.QByteArray get_native(long __this__nativeId);
            
            
            @Override
            @io.qt.QtUninvokable
            public boolean equals(io.qt.qt3d.render.QBufferDataGenerator other){
                java.util.Objects.requireNonNull(other, "Argument 'other': null not expected.");
                return equals_native_cref_Qt3DRender_QBufferDataGenerator_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(other));
            }
            private native static boolean equals_native_cref_Qt3DRender_QBufferDataGenerator_constfct(long __this__nativeId, long other);
            
        }
        
        
        public Impl(){
            super((QPrivateConstructor)null);
            initialize_native(this);
        }
        
        private native static void initialize_native(QBufferDataGenerator instance);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qbufferdatagenerator.html#operator-28-29">Qt3DRender::QBufferDataGenerator::operator()()</a></p>
         */
        @io.qt.QtUninvokable
        public abstract io.qt.core.QByteArray get();
        
        private native static io.qt.core.QByteArray get_native(long __this__nativeId);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qbufferdatagenerator.html#operator-eq-eq">Qt3DRender::QBufferDataGenerator::operator==(Qt3DRender::QBufferDataGenerator)const</a></p>
         */
        @io.qt.QtUninvokable
        public abstract boolean equals(io.qt.qt3d.render.QBufferDataGenerator other);
        
        private native static boolean equals_native_cref_Qt3DRender_QBufferDataGenerator_constfct(long __this__nativeId, long other);
        
        /**
         * Constructor for internal use only.
         * @param p expected to be <code>null</code>.
         */
        @io.qt.NativeAccess
        protected Impl(QPrivateConstructor p) { super(p); } 
        

        @Override
        @io.qt.QtUninvokable
        public boolean equals(Object other) {
            if (other instanceof io.qt.qt3d.render.QBufferDataGenerator) {
                return equals((io.qt.qt3d.render.QBufferDataGenerator) other);
            }

            return false;
        }

    }

    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qbufferdatagenerator.html#operator-28-29">Qt3DRender::QBufferDataGenerator::operator()()</a></p>
     */
    @io.qt.QtUninvokable
    public io.qt.core.QByteArray get();
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3drender-qbufferdatagenerator.html#operator-eq-eq">Qt3DRender::QBufferDataGenerator::operator==(Qt3DRender::QBufferDataGenerator)const</a></p>
     */
    @io.qt.QtUninvokable
    public default boolean equals(io.qt.qt3d.render.QBufferDataGenerator other){
        return this==other;
    }
    
}
